@@ -86,7 +86,7 @@
 #define KDESU_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KDESU_NO_DEPRECATED
-#  define KDESU_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54a00
+#  define KDESU_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55200
 #endif
 #ifdef KDESU_NO_DEPRECATED_WARNINGS
 #  define KDESU_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KDESU_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KDESU_DEPRECATED_WARNINGS_SINCE KDESU_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KDESU_DEPRECATED_WARNINGS_SINCE 0x54a00
+#    define KDESU_DEPRECATED_WARNINGS_SINCE 0x55200
 #  endif
 #endif
 
@@ -118,5 +118,12 @@
 #define KDESU_DEPRECATED_VERSION_5(minor, text)      KDESU_DEPRECATED_VERSION_5_##minor(text)
 #define KDESU_DEPRECATED_VERSION(major, minor, text) KDESU_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KDESU_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KDESU_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
+#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
+#  define KDESU_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KDESU_DEPRECATED_VERSION(major, minor, text)
+#  define KDESU_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KDESU_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#else
+#  define KDESU_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
+#  define KDESU_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#endif
 
 #endif /* KDESU_EXPORT_H */
